==> ToolChain_STM32_1.0.45.tar.bz: ToolChain_STM32_1.0.45/Template/additionals/examples/example_i2c.c <==
/*{ TemplateName::.c ************************************************
 
 Empty template for new c-files.
 Copy and adapt to your needs.
 
}*/

#include "example_i2c.h"

//{ Global variables *************************************************

ttc_i2c_generic_t       I2C_Generic;  // architecture independent I2C configuration
ttc_i2c_architecture_t  I2C_Arch;     // architecture specific I2C configuration
#define I2C_INDEX 2                   // using first I2C available on current board
u8_t Address_InertialSensor = 29;
u16_t AmountTransfers = 0;

//} Global variables
//{ Function definitions *************************************************

void example_i2c_init() {
#ifdef EXTENSION_400_lcd_320x240_olimex
    RCC_APB1PeriphClockCmd(RCC_APB1Periph_USART2, ENABLE);

    GPIO_InitTypeDef GPIO_InitStructure;
    GPIO_InitStructure.GPIO_Pin = GPIO_Pin_All;
    GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AIN;
    GPIO_Init(GPIOA, &GPIO_InitStructure);
    GPIO_Init(GPIOB, &GPIO_InitStructure);
    GPIO_Init(GPIOC, &GPIO_InitStructure);
    GPIO_Init(GPIOD, &GPIO_InitStructure);
    GPIO_Init(GPIOE, &GPIO_InitStructure);
    GPIO_Init(GPIOF, &GPIO_InitStructure);
    GPIO_Init(GPIOG, &GPIO_InitStructure);

    /* Enable the FSMC Clock */
    RCC_AHBPeriphClockCmd(RCC_AHBPeriph_FSMC, ENABLE);

    LCD_Init();
    LCD_SetBacklight(1);
    LCD_Clear(LCD_COLOR_YELLOW);
#endif

    u8_t MaxI2C = ttc_i2c_get_max_index();
    Assert(MaxI2C > 0, ec_UNKNOWN);

    ttc_i2c_errorcode_e Error;

    Error = ttc_i2c_get_defaults(I2C_INDEX, &I2C_Generic);
    Assert( Error == tie_OK, ec_UNKNOWN);

    #ifdef EXTENSION_600_example_i2c_master
    I2C_Generic.Flags.Bits.Master = 1;
    #else
    I2C_Generic.Flags.Bits.Slave = 1;
    #endif

    //I2C_Generic.Flags.Bits.
    Error = ttc_i2c_init(I2C_INDEX, &I2C_Generic, &I2C_Arch);
    Assert( Error == tie_OK, ec_UNKNOWN);
}
void example_i2c_start() {
    example_i2c_init();

#ifdef EXTENSION_600_example_i2c_master
    ttc_task_create(task_I2C_master,                 // function to start as thread
                  (const signed char*) "I2Ctx",      // thread name (just for debugging)
                  (size_t) 512,                      // stack size
                  (void *) NULL,                     // passed as argument to taskLEDs()
                  (unsigned portBASE_TYPE) 1,        // task priority (higher values mean more process time)
                  (void*) NULL                       // can return a handle to created task
                  );
#else
    ttc_task_create(task_I2C_slave,                // function to start as thread
                  (const signed char*) "I2Crx",      // thread name (just for debugging)
                  (size_t) 512,                      // stack size
                  (void *) NULL,                     // passed as argument to taskLEDs()
                  (unsigned portBASE_TYPE) 1,        // task priority (higher values mean more process time)
                  (void*) NULL                       // can return a handle to created task
                  );
#endif
}
void task_I2C_master(void *pvParameters) {
    pvParameters = pvParameters; // avoids warning: unused parameter 'pvParameters'

    while (1) {
        uSleep(10);
    }
}
void task_I2C_slave(void *pvParameters) {
    pvParameters = pvParameters; // avoids warning: unused parameter 'pvParameters'

#define Size_ReceiveBuffer 20
    char ReceiveBuffer[Size_ReceiveBuffer];
    ReceiveBuffer[0] = 0;
    //char* Writer = ReceiveBuffer;
    //char* WriterEnd = Writer + Size_ReceiveBuffer - 1;

    while (1) {
        // ToDo: implement I2C-slave


        uSleep(1);
    }
}


//} Function definitions

==> ToolChain_STM32_1.0.46.tar.bz: ToolChain_STM32_1.0.46/Template/additionals/examples/example_i2c.c <==
/*{ TemplateName::.c ************************************************
 
 Empty template for new c-files.
 Copy and adapt to your needs.
 
}*/

#include "example_i2c.h"

//{ Global variables *************************************************

ttc_i2c_generic_t       I2C_Generic;  // architecture independent I2C configuration
ttc_i2c_architecture_t  I2C_Arch;     // architecture specific I2C configuration
#define I2C_INDEX 2                   // using first I2C available on current board
u8_t Address_InertialSensor = 29;
u16_t AmountTransfers = 0;

//} Global variables
//{ Function definitions *************************************************

void example_i2c_init() {
#ifdef EXTENSION_400_lcd_320x240_olimex
    RCC_APB1PeriphClockCmd(RCC_APB1Periph_USART2, ENABLE);

    GPIO_InitTypeDef GPIO_InitStructure;
    GPIO_InitStructure.GPIO_Pin = GPIO_Pin_All;
    GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AIN;
    GPIO_Init(GPIOA, &GPIO_InitStructure);
    GPIO_Init(GPIOB, &GPIO_InitStructure);
    GPIO_Init(GPIOC, &GPIO_InitStructure);
    GPIO_Init(GPIOD, &GPIO_InitStructure);
    GPIO_Init(GPIOE, &GPIO_InitStructure);
    GPIO_Init(GPIOF, &GPIO_InitStructure);
    GPIO_Init(GPIOG, &GPIO_InitStructure);

    /* Enable the FSMC Clock */
    RCC_AHBPeriphClockCmd(RCC_AHBPeriph_FSMC, ENABLE);

    LCD_Init();
    LCD_SetBacklight(1);
    LCD_Clear(LCD_COLOR_WHITE);
    LCD_ConSetColor(LCD_COLOR_WHITE, LCD_COLOR_BLUE);
#endif

    u8_t MaxI2C = ttc_i2c_get_max_index();
    Assert(MaxI2C > 0, ec_UNKNOWN);

    ttc_i2c_errorcode_e Error;

    Error = ttc_i2c_get_defaults(I2C_INDEX, &I2C_Generic);
    Assert( Error == tie_OK, ec_UNKNOWN);

    #ifdef EXTENSION_600_example_i2c_master
    I2C_Generic.Flags.Bits.Master = 1;
    #else
    I2C_Generic.Flags.Bits.Slave = 1;
    #endif

    //I2C_Generic.Flags.Bits.
    Error = ttc_i2c_init(I2C_INDEX, &I2C_Generic, &I2C_Arch);
    Assert( Error == tie_OK, ec_UNKNOWN);

}
void example_i2c_start() {
    example_i2c_init();

#ifdef EXTENSION_600_example_i2c_master
    ttc_task_create(task_I2C_master,                 // function to start as thread
                  (const signed char*) "I2Ctx",      // thread name (just for debugging)
                  (size_t) 512,                      // stack size
                  (void *) NULL,                     // passed as argument to taskLEDs()
                  (unsigned portBASE_TYPE) 1,        // task priority (higher values mean more process time)
                  (void*) NULL                       // can return a handle to created task
                  );
#else
    ttc_task_create(task_I2C_slave,                // function to start as thread
                  (const signed char*) "I2Crx",      // thread name (just for debugging)
                  (size_t) 512,                      // stack size
                  (void *) NULL,                     // passed as argument to taskLEDs()
                  (unsigned portBASE_TYPE) 1,        // task priority (higher values mean more process time)
                  (void*) NULL                       // can return a handle to created task
                  );
#endif
}
void task_I2C_master(void *pvParameters) {
    pvParameters = pvParameters; // avoids warning: unused parameter 'pvParameters'


#ifdef EXTENSION_400_sensor_lis3lv02dl
    LCD_ConSetPos(0,0);
    LCD_Printf("LIS3LV02DL ??");

    lis3lv02dl_errorcode_e SensorError;
    SensorError = i2c_lis3lv02dl_init(I2C_INDEX);
    Assert(SensorError == lie_OK, ec_UNKNOWN);

    u8_t StatusRegister = 0;
    ttc_i2c_read_register(I2C_INDEX, I2C_ADDRESS_LIS3LV02DL, LIS_REG_WHO_AM_I, tiras_MSB_First_8Bit, &StatusRegister);
    Assert(StatusRegister == 0x3A, ec_DeviceNotFound);

    LCD_ConSetPos(0,11);
    LCD_Printf("OK");

#endif

    while (1) {

        // ToDo: read data from sensor + display data on LCD...

        mSleep(10);
    }
}
void task_I2C_slave(void *pvParameters) {
    pvParameters = pvParameters; // avoids warning: unused parameter 'pvParameters'

#define Size_ReceiveBuffer 20
    char ReceiveBuffer[Size_ReceiveBuffer];
    ReceiveBuffer[0] = 0;
    //char* Writer = ReceiveBuffer;
    //char* WriterEnd = Writer + Size_ReceiveBuffer - 1;

    while (1) {
        // ToDo: implement I2C-slave


        uSleep(1);
    }
}


//} Function definitions
